==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/cloudfront/kotlin/inputs/ResponseHeadersPolicyRemoveHeadersConfigItemArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudfront.kotlin.inputs

import com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyRemoveHeadersConfigItemArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property header The HTTP response header name.
 */
public data class ResponseHeadersPolicyRemoveHeadersConfigItemArgs(
    public val `header`: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyRemoveHeadersConfigItemArgs> {
    override fun toJava():
        com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyRemoveHeadersConfigItemArgs =
        com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyRemoveHeadersConfigItemArgs.builder()
            .`header`(`header`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ResponseHeadersPolicyRemoveHeadersConfigItemArgs].
 */
@PulumiTagMarker
public class ResponseHeadersPolicyRemoveHeadersConfigItemArgsBuilder internal constructor() {
    private var `header`: Output<String>? = null

    /**
     * @param value The HTTP response header name.
     */
    @JvmName("cceggwgrvfmfaioy")
    public suspend fun `header`(`value`: Output<String>) {
        this.`header` = value
    }

    /**
     * @param value The HTTP response header name.
     */
    @JvmName("fcxcvxqlchbpfcnv")
    public suspend fun `header`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`header` = mapped
    }

    internal fun build(): ResponseHeadersPolicyRemoveHeadersConfigItemArgs =
        ResponseHeadersPolicyRemoveHeadersConfigItemArgs(
            `header` = `header` ?: throw PulumiNullFieldException("header"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/cloudfront/kotlin/inputs/ResponseHeadersPolicyRemoveHeadersConfigItemArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudfront.kotlin.inputs

import com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyRemoveHeadersConfigItemArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property header
 */
public data class ResponseHeadersPolicyRemoveHeadersConfigItemArgs(
    public val `header`: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyRemoveHeadersConfigItemArgs> {
    override fun toJava(): com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyRemoveHeadersConfigItemArgs =
        com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyRemoveHeadersConfigItemArgs.builder()
            .`header`(`header`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ResponseHeadersPolicyRemoveHeadersConfigItemArgs].
 */
@PulumiTagMarker
public class ResponseHeadersPolicyRemoveHeadersConfigItemArgsBuilder internal constructor() {
    private var `header`: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("ddfvmkswvjtglofl")
    public suspend fun `header`(`value`: Output<String>) {
        this.`header` = value
    }

    /**
     * @param value
     */
    @JvmName("dhfpdrskbfipwagf")
    public suspend fun `header`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`header` = mapped
    }

    internal fun build(): ResponseHeadersPolicyRemoveHeadersConfigItemArgs =
        ResponseHeadersPolicyRemoveHeadersConfigItemArgs(
            `header` = `header` ?: throw PulumiNullFieldException("header"),
        )
}
